@@ -35,19 +35,19 @@ function CMenu(win) {
     this.tm.bgcolors[2]         = new TreeMenuBgcolor("#f5f4e2", "#ffffff", "#c2c1b2");
     this.tm.bgcolors[3]         = new TreeMenuBgcolor("#fefeee", "#cccbbc", "#cccbbc");
     this.tm.bgcolorMarked       = "#ffcc33";
-    this.tm.stsTreeNode         = "<<STATUS_TEXT_TREE_NODE>>";
-    this.tm.stsDocument         = "<<STATUS_TEXT_TREE_DOCUMENT>>";
-    this.tm.stsExpand           = "<<STATUS_TEXT_TREE_EXPAND>>";
-    this.tm.stsCollapse         = "<<STATUS_TEXT_TREE_COLLAPSE>>";
+    this.tm.stsTreeNode         = "Node";
+    this.tm.stsDocument         = "Document";
+    this.tm.stsExpand           = "Click Here To Expand the Subtree";
+    this.tm.stsCollapse         = "Click Here To Compress the Subtree";
     this.tm.a11y                = true;
-    this.tm.a11yEnter           = "<<A11Y_TREE_ENTER>>";
-    this.tm.a11yLeave           = "<<A11Y_TREE_LEAVE>>";
-    this.tm.a11yLevel           = "<<A11Y_TREE_LEVEL>>";
-    this.tm.a11yExpanded        = "<<A11Y_TREE_EXPANDED>>";
-    this.tm.a11ySelected        = "<<A11Y_TREE_SELECTED>>";
+    this.tm.a11yEnter           = "Entering navigation tree";
+    this.tm.a11yLeave           = "Leaving navigation tree";
+    this.tm.a11yLevel           = "Level";
+    this.tm.a11yExpanded        = "Expanded";
+    this.tm.a11ySelected        = "Selected";
     this.tm.itemGo              = PH_itemGo;
 
-    this.stsStructLink          = "<<STATUS_TEXT_TREE_STRUCTLINK>>";
+    this.stsStructLink          = "Structure link";
     this.imgItemStructLink      = new Image();
     this.imgItemStructLink.src  = "../../images/change_book.gif";
 
@@ -114,3 +114,4 @@ function PH_itemGo(item) {
         top[target].location = item.href;
     }
 }
+
